OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Feil passord",
    "The new password can not be the same as the previous one" : "Det nye passordet kan ikke være det samme som det forrige",
    "No user supplied" : "Ingen bruker angitt",
    "Authentication error" : "Autentiseringsfeil",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vennligst oppgi et administrativt gjenopprettingspassord. Ellers vil alle brukerdata gå tapt",
    "Wrong admin recovery password. Please check the password and try again." : "Feil administrativt gjenopprettingspassord. Sjekk passordet og prøv igjen.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Serveren støtter ikke endring av passord, men oppdatering av brukerens krypteringsnøkkel var vellykket.",
    "Unable to change password" : "Kunne ikke endre passord",
    "%s password changed successfully" : "%s passord ble endret",
    "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installering og oppdatering av apper via app-butikken eller ved deling i Forent sky",
    "Federated Cloud Sharing" : "Forent sky-deling",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL bruker en utdatert %s-versjon (%s). Vennligst oppdater operativsystemet ditt; ellers vil ikke funksjoner som %s virke korrekt.",
    "A problem occurred, please check your log files (Error: %s)" : "Det oppstod et problem. Sjekk loggfilene (Feil: %s)",
    "Migration Completed" : "Migrering ferdig",
    "Group already exists." : "Gruppe finnes allerede.",
    "Unable to add group." : "Kan ikke legge til gruppe.",
    "Unable to delete group." : "Kan ikke slette gruppe.",
    "log-level out of allowed range" : "Loggnivå utenfor tillatt område",
    "Saved" : "Lagret",
    "test email settings" : "Test av innstillinger for e-post",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Et problem oppstod med sending av e-post. Sjekk innstillingene. (Feil: %s)",
    "Email sent" : "E-post sendt",
    "You need to set your user email before being able to send test emails." : "Du må sette e-postadressen for brukeren din før du kan teste sending av e-post.",
    "Couldn't change the email address because the user does not exist" : "Kunne ikke endre epost-adressen fordi brukeren ikke finnes",
    "Couldn't change the email address because the token is invalid" : "Kunne ikke endre epost-adressen fordi symbolet er ugyldig",
    "Invalid mail address" : "Ugyldig e-postadresse",
    "A user with that name already exists." : "Det finnes allerede en bruker med det navnet.",
    "Unable to create user." : "Kan ikke opprette bruker.",
    "Your %s account was created" : "%s-kontoen din ble opprettet",
    "Unable to delete user." : "Kan ikke slette bruker.",
    "Forbidden" : "Forbudt",
    "Invalid user" : "Ugyldig bruker",
    "Unable to change mail address" : "Kan ikke endre epost-adresse",
    "Email has been changed successfully." : "E-post ble endret",
    "An email has been sent to this address for confirmation" : "En e-post ble sendt til denne adressen for bekreftelse",
    "No email was sent because you already sent one recently. Please try again later." : "Ingen e-post ble sendt fordi du allerede har sendt en nylig. Prøv igjen senere.",
    "Your full name has been changed." : "Ditt fulle navn er blitt endret.",
    "Unable to change full name" : "Klarte ikke å endre fullt navn",
    "%s email address confirm" : "%s e-postadresse bekreft",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Klarte ikke å sende bekreftelses-epost om endring av epost-adresse. Kontakt administratoren.",
    "%s email address changed successfully" : "%s epost-adresse endret",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Klarte ikke å sende varsel-epost om endring av epost-adresse. Kontakt administratoren.",
    "Unable to enable/disable user." : "Kan ikke aktivere/deaktivere bruker.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Språk endret",
    "Invalid request" : "Ugyldig forespørsel",
    "Admins can't remove themself from the admin group" : "Admin kan ikke flytte seg selv fra admingruppen",
    "Unknown user" : "Ukjent bruker",
    "Couldn't remove app." : "Klarte ikke å fjerne app.",
    "Official" : "Offisiell",
    "Approved" : "Godkjent",
    "All" : "Alle",
    "Enabled" : "Aktiv",
    "Not enabled" : "Ikke aktivert",
    "No apps found for your version" : "Ingen apper funnet for din versjon",
    "The app will be downloaded from the app store" : "Appen vil bli lastet ned fra app-butikken",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offisielle apper utvikles av og innenfor ownCloud-fellesskapet. De tilbyr funksjonalitet som er sentral for ownCloud og er forberedt for produksjonsbruk.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkjente apper er utviklet av tiltrodde utviklere og har gjennomgått en rask sikkerhetssjekk. De vedlikeholdes aktivt i et åpent kode-depot og utviklerne anser dem for å være stabile for tidvis eller normal bruk.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Denne appen er ikke sjekket for sikkerhetsproblemer og er ny eller ansett for å være ustabil. Installer på egen risiko.",
    "Please wait...." : "Vennligst vent...",
    "Error while disabling app" : "Deaktivering av app feilet",
    "Disable" : "Deaktiver ",
    "Enable" : "Aktiver",
    "Error while enabling app" : "Aktivering av app feilet",
    "Error: this app cannot be enabled because it makes the server unstable" : "Feil: Denne appen kan ikke aktiveres fordi den gjør serveren ustabil",
    "Error: could not disable broken app" : "Feil: Kunne ikke deaktivere ustabil app",
    "Error while disabling broken app" : "Feil ved deaktivering av ustabil app",
    "Updating...." : "Oppdaterer...",
    "Error while updating app" : "Feil ved oppdatering av app",
    "Updated" : "Oppdatert",
    "Uninstalling ...." : "Avinstallerer ....",
    "Error while uninstalling app" : "Feil ved avinstallering av app",
    "Uninstall" : "Avinstaller",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli omdirigert til oppdateringssiden om 5 sekunder.",
    "App update" : "Oppdatering av applikasjon",
    "Experimental" : "Eksperimentell",
    "No apps found for {query}" : "Ingen apper funnet for \"{query}\"",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ønsker du virkelig å legge til \"{domain}\" som klarert domene?",
    "Add trusted domain" : "Legg til et klarert domene",
    "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til migreringen er ferdig.",
    "Migration started …" : "Migrering startet ..",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Vennligst last opp et ASCII-kodet PEM-sertifikat.",
    "Valid until {date}" : "Gyldig til {date}",
    "Delete" : "Slett",
    "Disconnect" : "Koble fra",
    "Error while loading browser sessions and device tokens" : "Feil ved lasting av nettleser-økter og enhetsnøkler",
    "Error while creating device token" : "Feil ved oppretting av enhetsnøkkel",
    "Error while deleting the token" : "Feil ved sletting av nøkkelen",
    "Sending..." : "Sender...",
    "Failed to change the email address." : "Klarte ikke å endre epost-adressen.",
    "Email changed successfully." : "E-post ble endret.",
    "An error occurred: {message}" : "Det oppstod en feil: {message}",
    "Select a profile picture" : "Velg et profilbilde",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "So-so-passord",
    "Good password" : "Bra passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "Unable to delete {objName}" : "Kan ikke slette {objName}",
    "Error creating group: {message}" : "Feil ved oppretting av gruppe: {message}",
    "A valid group name must be provided" : "Et gyldig gruppenavn må oppgis",
    "deleted {groupName}" : "slettet {groupName}",
    "undo" : "angre",
    "never" : "aldri",
    "deleted {userName}" : "slettet {userName}",
    "add group" : "legg til gruppe",
    "Invalid quota value \"{val}\"" : "Ugyldig kvoteverdi \"{val}\"",
    "enabled" : "aktivert",
    "disabled" : "deaktivert",
    "User {uid} has been {state}!" : "Bruker {uid} er blitt {state}!",
    "no group" : "ingen gruppe",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Forandring av passordet vil føre til tap av data, fordi datagjennoppretting er utilgjengelig for denne brukeren",
    "Password successfully changed" : "Passordet ble endret",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "Error creating user: {message}" : "Feil ved oppretting av bruker: {message}",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "A valid email must be provided" : "En gyldig e-postadresse må oppgis",
    "Use the following link to confirm your changes to the email address: {link}" : "Bruk følgende lenke for å bekrefte din endring av epost-adressen: {link}",
    "Email address changed to {mailAddress} successfully." : "E-post ble endret til {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hei,<br><br>vil bare informere om at du nå har en %s-konto.<br><br>Brukernavnet ditt: %s<br>Gå dit: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Ha det!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hei,\n\nVil bare informere om at du nå har en %s-konto.\n\nBrukernavnet ditt: %s\nGå dit: %s\n\n",
    "User documentation" : "Brukerdokumentasjon",
    "Administrator documentation" : "Administratordokumentasjon",
    "Online documentation" : "Elektronisk dokumentasjon",
    "Forum" : "Forum",
    "Issue tracker" : "Problemsporing",
    "Commercial support" : "Forretningsstøtte",
    "Apps Management" : "App-administrering",
    "Developer documentation" : "Utviklerdokumentasjon",
    "by %s" : "av %s",
    "%s-licensed" : "%s-lisensiert",
    "Documentation:" : "Dokumentasjon:",
    "Admin documentation" : "Admin-dokumentasjon",
    "Visit website" : "Gå til nettside",
    "Report a bug" : "Rapporter en feil",
    "Show description …" : "Vis beskrivelse …",
    "Hide description …" : "Skjul beskrivelse …",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne appen har ingen minimumsversjon av ownCloud. Dette vil være en feil i ownCloud 11 og senere.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne appen har ingen maksimumsversjon av ownCloud. Dette vil være en feil i ownCloud 11 og senere.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denne appen kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt:",
    "Enable only for specific groups" : "Aktiver kun for visse grupper",
    "Uninstall App" : "Avinstaller app",
    "Show enabled apps" : "Vis aktiverte apper",
    "Show disabled apps" : "Vis deaktiverte apper",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Siste kjøring av cron-jobb: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Siste kjøring av cron-jobb: %s. Noe ser ut til å være galt.",
    "Cron was not executed yet!" : "Cron er ikke utført ennå!",
    "Open documentation" : "Åpne dokumentasjonen",
    "Execute one task with each page loaded" : "Utfør en oppgave med hver side som blir lastet",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er registrert i en webcron-tjeneste for å kalle cron.php hvert 15. minutt over http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Bruk systemets cron-tjeneste til å kalle cron.php hvert 15. minutt.",
    "SSL Root Certificates" : "SSL rotsertifikater",
    "Common Name" : "Vanlig navn",
    "Valid until" : "Gyldig til",
    "Issued By" : "Utstedt av",
    "Valid until %s" : "Gyldig til %s",
    "Import root certificate" : "Importer rotsertifikat",
    "Server-side encryption" : "Serverkryptering",
    "Enable server-side encryption" : "Aktiver serverkryptering",
    "Please read carefully before activating server-side encryption: " : "Vennligst les dette nøye før du aktiverer serverkrykptering:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er blitt aktivert, vil alle filer som lastes opp til serveren fra det tidspunktet av bli lagret kryptert på serveren. Det vil kun være mulig å deaktivere kryptering senere dersom den aktive krypteringsmodulen støtter det og alle forutsetninger (f.eks. å sette en gjenopprettingsnøkkel) er til stede.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Kryptering alene garanterer ikke sikkerheten i systemet. Se ownCloud-dokumentasjonen for mer informasjon om hvordan krypterings-appen virker og hvilke brukstilfeller som støttes.",
    "Be aware that encryption always increases the file size." : "Vær oppmerksom på at kryptering alltid øker filstørrelsen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er alltid bra å ta regelmessig sikkerhetskopi av dataene dine. Pass på å ta kopi av krypteringsnøklene sammen med dataene når kryptering er i bruk.",
    "This is the final warning: Do you really want to enable encryption?" : "Dette er siste advarsel: Vil du virkelig aktivere kryptering?",
    "Enable encryption" : "Aktiver kryptering",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul er lastet. Aktiver en krypteringsmodul i app-menyen.",
    "Select default encryption module:" : "Velg standard krypteringsmodul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye. Vennligst aktiver \"Standard krypteringsmodul\" og kjør 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye.",
    "Start migration" : "Start migrering",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "Tillat apper å bruke API for Deling",
    "Allow users to share via link" : "Tillat brukere å dele via lenke",
    "Allow public uploads" : "Tillat offentlig opplasting",
    "Enforce password protection" : "Krev passordbeskyttelse",
    "Set default expiration date" : "Sett standard utløpsdato",
    "Allow users to send mail notification for shared files" : "Tlllat at brukere sender e-postvarsler for delte filer",
    "Allow users to share file via social media" : "Tillat brukere å dele fil via sosiale medier",
    "Expire after " : "Utløper etter",
    "days" : "dager",
    "Enforce expiration date" : "Krev utløpsdato",
    "Allow resharing" : "TIllat videre deling",
    "Allow sharing with groups" : "Tillat deling med grupper",
    "Restrict users to only share with users in their groups" : "Begrens brukere til kun å dele med brukere i deres grupper",
    "Allow users to send mail notification for shared files to other users" : "Tillat at brukere sender varsler om delte filer på e-post til andre brukere",
    "Exclude groups from sharing" : "Utelukk grupper fra deling",
    "These groups will still be able to receive shares, but not to initiate them." : "Disse gruppene vil fremdeles kunne motta delinger men ikke lage dem.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Tillat automatisk fullføring av brukernavn i delingsdialogen. Uten dette valget må hele brukernavnet oppgis.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alt (fatale problemer, feil, advarsler, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, advarsler, feil og fatale problemer",
    "Warnings, errors and fatal issues" : "Advarsler, feil og fatale problemer",
    "Errors and fatal issues" : "Feil og fatale problemer",
    "Fatal issues only" : "Kun fatale problemer",
    "Log" : "Logg",
    "What to log" : "Hva som skal logges",
    "Download logfile (%s)" : "Last ned loggfil (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Loggfilen er over 100 MB, nedlastingen kan ta en stund!",
    "None" : "Ingen",
    "Login" : "Logg inn",
    "Plain" : "Enkel",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-postserver",
    "This is used for sending out notifications." : "Dette brukes for utsending av varsler.",
    "Send mode" : "Sendemåte",
    "Encryption" : "Kryptering",
    "From address" : "Fra adresse",
    "mail" : "e-post",
    "Authentication method" : "Autentiseringsmetode",
    "Authentication required" : "Autentisering kreves",
    "Server address" : "Server-adresse",
    "Port" : "Port",
    "Credentials" : "Påloggingsdetaljer",
    "SMTP Username" : "SMTP-brukernavn",
    "SMTP Password" : "SMTP-passord",
    "Store credentials" : "Lagre påloggingsdetaljer",
    "Test email settings" : "Test innstillinger for e-post",
    "Send email" : "Send e-post",
    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ser ikke ut til å være satt opp riktig for å lese systemets miljøvariabler. Testen med getenv(\"PATH\") returnerer bare et tomt svar.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Vennligst sjekk <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installasjonsdokumentasjonen ↗</a> etter php konfigurasjonsnotater og konfigurering av php på serveren din, særlig om du bruker php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivebeskyttede konfigurasjonen er blitt aktivert. Dette forhindrer setting av visse konfigureringer via web-grensesnittet. Videre må config-filen gjøres skrivbar manuelt for hver oppdatering.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen din kjører ikke med transaksjonsisoleringsnivå \"READ COMMITED\". Dette kan føre til problemer når flere handlinger kjøres parallelt.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s lavere enn versjon %2$s er installert. Vi anbefaler å oppgradere til en nyere %1$s-versjon for å få bedre stabilitet og ytelse.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modulen 'fileinfo' mangler. Vi anbefaler at du aktiverer denne modulen for å kunne detektere mime-typen korrekt.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing er deaktivert. Dette kan føre til konflikt. Aktiver \"filelocking.enabled\" i config.php for å unngå disse problemene. Se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing bør konfigureres til å bruke minnebasert låsing, ikke databasert låsing, som er standard men tregere i bruk. Se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
    "System locale can not be set to a one which supports UTF-8." : "Kan ikke sette systemets nasjonale innstillinger til en som støtter UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Dette betyr at det kan forekomme problemer med visse tegn i filnavn.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vi anbefaler sterkt å installere de påkrevde pakkene på systemet ditt for å støtte en av følgende nasjonale innstillinger: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Hvis installasjonen din ikke er installert i roten av domenet og bruker systemets cron, kan det bli problemer med URL-genereringen. For å unngå disse problemene, sett \"overwrite.cli.url\" i filen config.php til web-roten for installasjonen din (Foreslått: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite brukes som database. For større installasjoner anbefaler vi å bytte til en annen database-server.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite er spesielt frarådet om man bruker desktopklienten til filsynkronisering",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: 'occ db:convert-type', eller les i <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Vi anbefaler aktivering av systemets cron, siden de andre cron-metodene kan gi dårligere ytelse eller stabilitet.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Det var ikke mulig å kjøre cron-jobben vi CLI. Følgende tekniske feil oppstod:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Vennligst dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installasjonsguidene ↗</a>, og se etter feil eller advarsler i <a href=\"#log-section\">loggen</a>.",
    "All checks passed." : "Alle sjekker bestått.",
    "System Status" : "Systemstatus",
    "Tips & tricks" : "Tips og triks",
    "How to do backups" : "Hvordan ta sikkerhetskopier",
    "Advanced monitoring" : "Avansert overvåking",
    "Performance tuning" : "Forbedre ytelsen",
    "Improving the config.php" : "Tilpasninger i config.php",
    "Theming" : "Temaer",
    "Hardening and security guidance" : "Herding og sikkerhetsveiledning",
    "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
    "Desktop client" : "Skrivebordsklient",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Hvis du vil støtte prosjektet kan du\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">delta i utviklingen</a>\n\t\t\teller\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spre budskapet</a>!",
    "Show First Run Wizard again" : "Vis \"Førstegangs veiviser\" på nytt",
    "Profile picture" : "Profilbilde",
    "Upload new" : "Last opp nytt",
    "Select from Files" : "Velg fra Filer",
    "Remove image" : "Fjern bilde",
    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
    "Cancel" : "Avbryt",
    "Choose as profile picture" : "Velg som profilbilde",
    "Full name" : "Fullt navn",
    "No display name set" : "Visningsnavn ikke satt",
    "Email" : "Epost",
    "Your email address" : "Din e-postadresse",
    "Change email" : "Endre e-post",
    "Set email" : "Sett e-post",
    "For password recovery and notifications" : "For passord-gjenoppretting og varsler",
    "No email address set" : "E-postadresse ikke satt",
    "You are member of the following groups:" : "Du er medlem av følgende grupper:",
    "Password" : "Passord",
    "Unable to change your password" : "Kunne ikke endre passordet ditt",
    "Current password" : "Nåværende passord",
    "New password" : "Nytt passord",
    "Change password" : "Endre passord",
    "Language" : "Språk",
    "Help translate" : "Bidra til oversettelsen",
    "Unlimited" : "Ubegrenset",
    "You are using %s of %s" : "Du bruker %s av %s",
    "You are using %s of %s (%s %%)" : "Du bruker %s av %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Utviklet av {communityopen}ownCloud-fellesskapet{linkclose}. {githubopen}Kildekoden{linkclose} er lisensiert under {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Økter",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Disse web-, skrivebords- og mobilklientene er pålogget din ownCloud for øyeblikket.",
    "Browser" : "Nettleser",
    "Most recent activity" : "Siste aktivitet",
    "App passwords" : "App-passord",
    "You've linked these apps." : "Du har lenket disse appene.",
    "Name" : "Navn",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Et app-passord er et passord som gir en app eller en enhet lov til å bruke %s-kontoen din.",
    "App name" : "App-navn",
    "Create new app password" : "Lag nytt app-passord",
    "Use the credentials below to configure your app or device." : "Bruk detaljene nedenfor til å konfigurere appen eller enheten din.",
    "Username" : "Brukernavn",
    "Done" : "Ferdig",
    "Version" : "Versjon",
    "Personal" : "Personlig",
    "Admin" : "Admin",
    "Error" : "Feil",
    "No panels for this section." : "Ingen paneler for denne seksjonen.",
    "Show enabled/disabled option" : "Vis valg for aktiv/inaktiv",
    "Show storage location" : "Vis lagringssted",
    "Show last log in" : "Vis site innlogging",
    "Show user backend" : "Vis bruker-server",
    "Send email to new user" : "Send e-post til ny bruker",
    "Show email address" : "Vis e-postadresse",
    "E-Mail" : "E-post",
    "Create" : "Opprett",
    "Admin Recovery Password" : "Administrativt gjenopprettingspassord",
    "Enter the recovery password in order to recover the users files during password change" : "Legg inn gjenopprettingspassordet for å gjenopprette brukerfilene når passordet endres",
    "Add Group" : "Legg til gruppe",
    "Group" : "Gruppe",
    "Everyone" : "Alle",
    "Admins" : "Administratorer",
    "Default Quota" : "Standard kvote",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Legg inn lagringskvote (f.eks. \"512 MB\" eller \"12 GB\")",
    "Other" : "Annet",
    "Full Name" : "Fullt navn",
    "Group Admin for" : "Gruppeadministrator for",
    "Quota" : "Kvote",
    "Storage Location" : "Lagringsplassering",
    "User Backend" : "Bruker-server",
    "Last Login" : "Siste innlogging",
    "change full name" : "endre fullt navn",
    "set new password" : "sett nytt passord",
    "change email address" : "endre e-postadresse",
    "Default" : "Standard",
    "Change" : "Endre",
    "Share" : "Delt ressurs",
    "installing and updating apps via the market or Federated Cloud Sharing" : "installering og oppdatering av apper via markedet eller ved deling i Forent sky",
    "White-listed Domains" : "Hvitelistede domener",
    "Domain" : "Domene",
    "Add Domain" : "Legg til domene",
    "CORS" : "CORS",
    "User ID" : "User ID",
    "Email address" : "E-postadresse",
    "Invalid email address" : "Ugyldig e-postadresse",
    "Restrict enumeration to group members" : "Begrens opplisting til gruppemedlemmer",
    "Extra field to display in autocomplete results" : "Ekstra felt som skal vises i autofullføringsresultater",
    "Restrict users to only share with groups they are member of" : "Begrens brukerne til å bare dele med grupper de er medlem av",
    "Default user and group share permissions" : "Standard rettigheter ved deling med brukere og grupper",
    "Enforce password protection for read-only links" : "Krev passordbeskyttelse for skrivebeskyttede linker",
    "Enforce password protection for read & write links" : "Krev passordbeskyttelse for les og skriv linker",
    "Enforce password protection for upload-only (File Drop) links" : "Krev passordbeskyttelse for bare opplasting (File Drop) linker",
    "You are using %s" : "Du bruker %s ",
    "No Domains." : "Ingen domener",
    "Are you sure you want to remove this domain?" : "Er du sikker på at du vil fjerne dette domenet?",
    "Add" : "Legg til",
    "Empty app name is not allowed." : "Tomt appnavn er ikke tillatt.",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Konfigureringsfilen er skrivebeskyttet. Korriger oppsettet ved å redigere filen manuelt.",
    "Email changed successfully for {user}." : "E-post ble endret for {user}.",
    "You are not a member of any groups." : "Du er ikke medlem av noen grupper.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "I et klyngeoppsett må config.php synkroniseress til alle noder.",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Dette er web-, desktop- og mobilklienter som for øyeblikket er logget på din %s,",
    "Automatically accept new incoming local user shares" : "Godta nye innkommende lokale brukerdelinger automatisk",
    "Legal" : "Juridisk informasjon",
    "Privacy Policy URL:" : "Personverns Regler URL:",
    "Privacy Policy URL" : "Personverns Regler URL",
    "App passwords / tokens" : "App-passord / tokens",
    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Et app-passord eller token er et passordfrase som gir en app eller en enhet lov til å bruke %s-kontoen din.",
    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Bruk dem som et sikkerhetstiltak for å skjule ditt faktiske passord som du kanskje bare vil bruke til webgrensesnittinnlogging.",
    "Create new app passcode" : "Lag nytt app-passord",
    "Password / Token" : "Password / Token",
    "Owner language" : "Eierspråk",
    "Language used for public mail notifications for shared files" : "Språk som brukes til offentlig postvarsling for delte filer",
    "Wrong current password" : "Feil nåværende passord",
    "The new password cannot be the same as the previous one" : "Det nye passordet kan ikke være det samme som det forrige"
},
"nplurals=2; plural=(n != 1);");
